========================
Neo 0.14.1 release notes
========================

14 April 25

This release of Neo includes many bug fixes in various IOs, a new HTML based repr, and fixes to the CI all with an eye toward our 1.0 release.

See all `pull requests`_ included in this release and the `list of closed issues`_.


Updated dependencies
--------------------

setuptools >= 78.0.2
numpy >= 1.24.4

Import improvements
-------------------

As part of our ongoing effort to improve the speed of importing Neo we have moved the library over to using :code:`importlib.util.find_spec`
rather than eagerly importing packages in :code:`try-except` blocks.

CI Improvements
---------------

The install for datalad/git-annex in the CI was fixed for our Python 3.12 tests allowing for all IOs to be tested on Python 3.9 and Python 3.12.
The buidling of documentation was improved by fixing code style errors.


HTML repr
---------

Thanks to the work of Heberto Mayorquin Neo now supports an html based repr. To see an example check out `html repr`_.


Bug fixes and improvements in IO modules
----------------------------------------

Bug fixes and/or improvements have been made to :code:`BlackRockIO`, :code:`SpikeGLXIO`, :code:`MaxwellIO`, :code:`IntanIO`, :code:`TdtIO`,
:code:`OpenEphysBinaryIO`, :code:`NeoMatlabIO`, :code:`EdfIO`, :code:`Neuralynx`, and :code:`SpikeGadgetsIO`.


Acknowledgements
----------------

Thanks to Heberto Mayorquin, Zach McKenzie, Andrew Davison, Alessio Buccino, Rémi Proville, Paul Adkisson, Baptiste Grimaud, 
Robert Wolff, Tommaso Lambresa, and Nina Kudryashova.



.. _`html repr` : https://github.com/NeuralEnsemble/python-neo/pull/1651

.. _`pull requests` : https://github.com/NeuralEnsemble/python-neo/pulls?q=is%3Apr+is%3Aclosed+milestone%3A0.14.1

.. _`list of closed issues` : https://github.com/NeuralEnsemble/python-neo/issues?q=is%3Aissue%20state%3Aclosed%20milestone%3A0.14.1